@@ -2,7 +2,7 @@
 **  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2013, The Trusted Domain Project.  All rights reserved.
+**  Copyright (c) 2009-2014, The Trusted Domain Project.  All rights reserved.
 */
 
 #ifndef _DKIM_H_
@@ -20,6 +20,9 @@ extern "C" {
 # include <stdbool.h>
 #endif /* HAVE_STDBOOL_H */
 #include <inttypes.h>
+#ifdef HAVE_LIMITS_H
+# include <limits.h>
+#endif /* HAVE_LIMITS_H */
 
 /*
 **  version -- 0xrrMMmmpp
@@ -30,7 +33,7 @@ extern "C" {
 **  	pp == patch number
 */
 
-#define	OPENDKIM_LIB_VERSION	0x02090100
+#define	OPENDKIM_LIB_VERSION	0x02090200
 
 #ifdef __STDC__
 # ifndef __P
